/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataLaunchdarklyFeatureFlagConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether to archive the flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#archived DataLaunchdarklyFeatureFlag#archived}
    */
    readonly archived?: boolean | cdktf.IResolvable;
    /**
    * A short description of what the flag will be used for
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#description DataLaunchdarklyFeatureFlag#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#id DataLaunchdarklyFeatureFlag#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether or not this flag should be made available to the client-side JavaScript SDK
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#include_in_snippet DataLaunchdarklyFeatureFlag#include_in_snippet}
    */
    readonly includeInSnippet?: boolean | cdktf.IResolvable;
    /**
    * A unique key that will be used to reference the flag in your code
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#key DataLaunchdarklyFeatureFlag#key}
    */
    readonly key: string;
    /**
    * The LaunchDarkly id of the user who will maintain the flag. If not set, the API will automatically apply the member associated with your Terraform API key or the most recently set maintainer
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#maintainer_id DataLaunchdarklyFeatureFlag#maintainer_id}
    */
    readonly maintainerId?: string;
    /**
    * The LaunchDarkly project key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#project_key DataLaunchdarklyFeatureFlag#project_key}
    */
    readonly projectKey: string;
    /**
    * Whether or not the flag is a temporary flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#temporary DataLaunchdarklyFeatureFlag#temporary}
    */
    readonly temporary?: boolean | cdktf.IResolvable;
    /**
    * client_side_availability block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#client_side_availability DataLaunchdarklyFeatureFlag#client_side_availability}
    */
    readonly clientSideAvailability?: DataLaunchdarklyFeatureFlagClientSideAvailability[] | cdktf.IResolvable;
    /**
    * custom_properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#custom_properties DataLaunchdarklyFeatureFlag#custom_properties}
    */
    readonly customProperties?: DataLaunchdarklyFeatureFlagCustomProperties[] | cdktf.IResolvable;
    /**
    * defaults block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#defaults DataLaunchdarklyFeatureFlag#defaults}
    */
    readonly defaults?: DataLaunchdarklyFeatureFlagDefaults;
    /**
    * variations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#variations DataLaunchdarklyFeatureFlag#variations}
    */
    readonly variations?: DataLaunchdarklyFeatureFlagVariations[] | cdktf.IResolvable;
}
export interface DataLaunchdarklyFeatureFlagClientSideAvailability {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#using_environment_id DataLaunchdarklyFeatureFlag#using_environment_id}
    */
    readonly usingEnvironmentId?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#using_mobile_key DataLaunchdarklyFeatureFlag#using_mobile_key}
    */
    readonly usingMobileKey?: boolean | cdktf.IResolvable;
}
export declare function dataLaunchdarklyFeatureFlagClientSideAvailabilityToTerraform(struct?: DataLaunchdarklyFeatureFlagClientSideAvailability | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagClientSideAvailabilityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagClientSideAvailability | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagClientSideAvailability | cdktf.IResolvable | undefined);
    private _usingEnvironmentId?;
    get usingEnvironmentId(): boolean | cdktf.IResolvable;
    set usingEnvironmentId(value: boolean | cdktf.IResolvable);
    resetUsingEnvironmentId(): void;
    get usingEnvironmentIdInput(): boolean | cdktf.IResolvable | undefined;
    private _usingMobileKey?;
    get usingMobileKey(): boolean | cdktf.IResolvable;
    set usingMobileKey(value: boolean | cdktf.IResolvable);
    resetUsingMobileKey(): void;
    get usingMobileKeyInput(): boolean | cdktf.IResolvable | undefined;
}
export declare class DataLaunchdarklyFeatureFlagClientSideAvailabilityList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagClientSideAvailability[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagClientSideAvailabilityOutputReference;
}
export interface DataLaunchdarklyFeatureFlagCustomProperties {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#key DataLaunchdarklyFeatureFlag#key}
    */
    readonly key: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#name DataLaunchdarklyFeatureFlag#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#value DataLaunchdarklyFeatureFlag#value}
    */
    readonly value: string[];
}
export declare function dataLaunchdarklyFeatureFlagCustomPropertiesToTerraform(struct?: DataLaunchdarklyFeatureFlagCustomProperties | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagCustomPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagCustomProperties | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagCustomProperties | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string[];
    set value(value: string[]);
    get valueInput(): string[] | undefined;
}
export declare class DataLaunchdarklyFeatureFlagCustomPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagCustomProperties[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagCustomPropertiesOutputReference;
}
export interface DataLaunchdarklyFeatureFlagDefaults {
    /**
    * The index of the variation served when the flag is off for new environments
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#off_variation DataLaunchdarklyFeatureFlag#off_variation}
    */
    readonly offVariation: number;
    /**
    * The index of the variation served when the flag is on for new environments
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#on_variation DataLaunchdarklyFeatureFlag#on_variation}
    */
    readonly onVariation: number;
}
export declare function dataLaunchdarklyFeatureFlagDefaultsToTerraform(struct?: DataLaunchdarklyFeatureFlagDefaultsOutputReference | DataLaunchdarklyFeatureFlagDefaults): any;
export declare class DataLaunchdarklyFeatureFlagDefaultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataLaunchdarklyFeatureFlagDefaults | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagDefaults | undefined);
    private _offVariation?;
    get offVariation(): number;
    set offVariation(value: number);
    get offVariationInput(): number | undefined;
    private _onVariation?;
    get onVariation(): number;
    set onVariation(value: number);
    get onVariationInput(): number | undefined;
}
export interface DataLaunchdarklyFeatureFlagVariations {
    /**
    * A description for the variation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#description DataLaunchdarklyFeatureFlag#description}
    */
    readonly description?: string;
    /**
    * A name for the variation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#name DataLaunchdarklyFeatureFlag#name}
    */
    readonly name?: string;
    /**
    * The value of the flag for this variation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag#value DataLaunchdarklyFeatureFlag#value}
    */
    readonly value: string;
}
export declare function dataLaunchdarklyFeatureFlagVariationsToTerraform(struct?: DataLaunchdarklyFeatureFlagVariations | cdktf.IResolvable): any;
export declare class DataLaunchdarklyFeatureFlagVariationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataLaunchdarklyFeatureFlagVariations | cdktf.IResolvable | undefined;
    set internalValue(value: DataLaunchdarklyFeatureFlagVariations | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class DataLaunchdarklyFeatureFlagVariationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataLaunchdarklyFeatureFlagVariations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataLaunchdarklyFeatureFlagVariationsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag launchdarkly_feature_flag}
*/
export declare class DataLaunchdarklyFeatureFlag extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "launchdarkly_feature_flag";
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/data-sources/feature_flag launchdarkly_feature_flag} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataLaunchdarklyFeatureFlagConfig
    */
    constructor(scope: Construct, id: string, config: DataLaunchdarklyFeatureFlagConfig);
    private _archived?;
    get archived(): boolean | cdktf.IResolvable;
    set archived(value: boolean | cdktf.IResolvable);
    resetArchived(): void;
    get archivedInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _includeInSnippet?;
    get includeInSnippet(): boolean | cdktf.IResolvable;
    set includeInSnippet(value: boolean | cdktf.IResolvable);
    resetIncludeInSnippet(): void;
    get includeInSnippetInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _maintainerId?;
    get maintainerId(): string;
    set maintainerId(value: string);
    resetMaintainerId(): void;
    get maintainerIdInput(): string | undefined;
    get name(): string;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    get tags(): string[];
    private _temporary?;
    get temporary(): boolean | cdktf.IResolvable;
    set temporary(value: boolean | cdktf.IResolvable);
    resetTemporary(): void;
    get temporaryInput(): boolean | cdktf.IResolvable | undefined;
    get variationType(): string;
    private _clientSideAvailability;
    get clientSideAvailability(): DataLaunchdarklyFeatureFlagClientSideAvailabilityList;
    putClientSideAvailability(value: DataLaunchdarklyFeatureFlagClientSideAvailability[] | cdktf.IResolvable): void;
    resetClientSideAvailability(): void;
    get clientSideAvailabilityInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagClientSideAvailability[] | undefined;
    private _customProperties;
    get customProperties(): DataLaunchdarklyFeatureFlagCustomPropertiesList;
    putCustomProperties(value: DataLaunchdarklyFeatureFlagCustomProperties[] | cdktf.IResolvable): void;
    resetCustomProperties(): void;
    get customPropertiesInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagCustomProperties[] | undefined;
    private _defaults;
    get defaults(): DataLaunchdarklyFeatureFlagDefaultsOutputReference;
    putDefaults(value: DataLaunchdarklyFeatureFlagDefaults): void;
    resetDefaults(): void;
    get defaultsInput(): DataLaunchdarklyFeatureFlagDefaults | undefined;
    private _variations;
    get variations(): DataLaunchdarklyFeatureFlagVariationsList;
    putVariations(value: DataLaunchdarklyFeatureFlagVariations[] | cdktf.IResolvable): void;
    resetVariations(): void;
    get variationsInput(): cdktf.IResolvable | DataLaunchdarklyFeatureFlagVariations[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
