/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FeatureFlagConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether to archive the flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#archived FeatureFlag#archived}
    */
    readonly archived?: boolean | cdktf.IResolvable;
    /**
    * A short description of what the flag will be used for
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#description FeatureFlag#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#id FeatureFlag#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether or not this flag should be made available to the client-side JavaScript SDK
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#include_in_snippet FeatureFlag#include_in_snippet}
    */
    readonly includeInSnippet?: boolean | cdktf.IResolvable;
    /**
    * A unique key that will be used to reference the flag in your code
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#key FeatureFlag#key}
    */
    readonly key: string;
    /**
    * The LaunchDarkly id of the user who will maintain the flag. If not set, the API will automatically apply the member associated with your Terraform API key or the most recently set maintainer
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#maintainer_id FeatureFlag#maintainer_id}
    */
    readonly maintainerId?: string;
    /**
    * A human-friendly name for the feature flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#name FeatureFlag#name}
    */
    readonly name: string;
    /**
    * The LaunchDarkly project key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#project_key FeatureFlag#project_key}
    */
    readonly projectKey: string;
    /**
    * Tags associated with your resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#tags FeatureFlag#tags}
    */
    readonly tags?: string[];
    /**
    * Whether or not the flag is a temporary flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#temporary FeatureFlag#temporary}
    */
    readonly temporary?: boolean | cdktf.IResolvable;
    /**
    * The uniform type for all variations. Can be either "boolean", "string", "number", or "json".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#variation_type FeatureFlag#variation_type}
    */
    readonly variationType: string;
    /**
    * client_side_availability block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#client_side_availability FeatureFlag#client_side_availability}
    */
    readonly clientSideAvailability?: FeatureFlagClientSideAvailability[] | cdktf.IResolvable;
    /**
    * custom_properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#custom_properties FeatureFlag#custom_properties}
    */
    readonly customProperties?: FeatureFlagCustomProperties[] | cdktf.IResolvable;
    /**
    * defaults block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#defaults FeatureFlag#defaults}
    */
    readonly defaults?: FeatureFlagDefaults;
    /**
    * variations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#variations FeatureFlag#variations}
    */
    readonly variations?: FeatureFlagVariations[] | cdktf.IResolvable;
}
export interface FeatureFlagClientSideAvailability {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#using_environment_id FeatureFlag#using_environment_id}
    */
    readonly usingEnvironmentId?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#using_mobile_key FeatureFlag#using_mobile_key}
    */
    readonly usingMobileKey?: boolean | cdktf.IResolvable;
}
export declare function featureFlagClientSideAvailabilityToTerraform(struct?: FeatureFlagClientSideAvailability | cdktf.IResolvable): any;
export declare class FeatureFlagClientSideAvailabilityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FeatureFlagClientSideAvailability | cdktf.IResolvable | undefined;
    set internalValue(value: FeatureFlagClientSideAvailability | cdktf.IResolvable | undefined);
    private _usingEnvironmentId?;
    get usingEnvironmentId(): boolean | cdktf.IResolvable;
    set usingEnvironmentId(value: boolean | cdktf.IResolvable);
    resetUsingEnvironmentId(): void;
    get usingEnvironmentIdInput(): boolean | cdktf.IResolvable | undefined;
    private _usingMobileKey?;
    get usingMobileKey(): boolean | cdktf.IResolvable;
    set usingMobileKey(value: boolean | cdktf.IResolvable);
    resetUsingMobileKey(): void;
    get usingMobileKeyInput(): boolean | cdktf.IResolvable | undefined;
}
export declare class FeatureFlagClientSideAvailabilityList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FeatureFlagClientSideAvailability[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FeatureFlagClientSideAvailabilityOutputReference;
}
export interface FeatureFlagCustomProperties {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#key FeatureFlag#key}
    */
    readonly key: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#name FeatureFlag#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#value FeatureFlag#value}
    */
    readonly value: string[];
}
export declare function featureFlagCustomPropertiesToTerraform(struct?: FeatureFlagCustomProperties | cdktf.IResolvable): any;
export declare class FeatureFlagCustomPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FeatureFlagCustomProperties | cdktf.IResolvable | undefined;
    set internalValue(value: FeatureFlagCustomProperties | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string[];
    set value(value: string[]);
    get valueInput(): string[] | undefined;
}
export declare class FeatureFlagCustomPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FeatureFlagCustomProperties[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FeatureFlagCustomPropertiesOutputReference;
}
export interface FeatureFlagDefaults {
    /**
    * The index of the variation served when the flag is off for new environments
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#off_variation FeatureFlag#off_variation}
    */
    readonly offVariation: number;
    /**
    * The index of the variation served when the flag is on for new environments
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#on_variation FeatureFlag#on_variation}
    */
    readonly onVariation: number;
}
export declare function featureFlagDefaultsToTerraform(struct?: FeatureFlagDefaultsOutputReference | FeatureFlagDefaults): any;
export declare class FeatureFlagDefaultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): FeatureFlagDefaults | undefined;
    set internalValue(value: FeatureFlagDefaults | undefined);
    private _offVariation?;
    get offVariation(): number;
    set offVariation(value: number);
    get offVariationInput(): number | undefined;
    private _onVariation?;
    get onVariation(): number;
    set onVariation(value: number);
    get onVariationInput(): number | undefined;
}
export interface FeatureFlagVariations {
    /**
    * A description for the variation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#description FeatureFlag#description}
    */
    readonly description?: string;
    /**
    * A name for the variation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#name FeatureFlag#name}
    */
    readonly name?: string;
    /**
    * The value of the flag for this variation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag#value FeatureFlag#value}
    */
    readonly value: string;
}
export declare function featureFlagVariationsToTerraform(struct?: FeatureFlagVariations | cdktf.IResolvable): any;
export declare class FeatureFlagVariationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FeatureFlagVariations | cdktf.IResolvable | undefined;
    set internalValue(value: FeatureFlagVariations | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class FeatureFlagVariationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FeatureFlagVariations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FeatureFlagVariationsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag launchdarkly_feature_flag}
*/
export declare class FeatureFlag extends cdktf.TerraformResource {
    static readonly tfResourceType = "launchdarkly_feature_flag";
    /**
    * Create a new {@link https://registry.terraform.io/providers/launchdarkly/launchdarkly/2.15.0/docs/resources/feature_flag launchdarkly_feature_flag} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FeatureFlagConfig
    */
    constructor(scope: Construct, id: string, config: FeatureFlagConfig);
    private _archived?;
    get archived(): boolean | cdktf.IResolvable;
    set archived(value: boolean | cdktf.IResolvable);
    resetArchived(): void;
    get archivedInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _includeInSnippet?;
    get includeInSnippet(): boolean | cdktf.IResolvable;
    set includeInSnippet(value: boolean | cdktf.IResolvable);
    resetIncludeInSnippet(): void;
    get includeInSnippetInput(): boolean | cdktf.IResolvable | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _maintainerId?;
    get maintainerId(): string;
    set maintainerId(value: string);
    resetMaintainerId(): void;
    get maintainerIdInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectKey?;
    get projectKey(): string;
    set projectKey(value: string);
    get projectKeyInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _temporary?;
    get temporary(): boolean | cdktf.IResolvable;
    set temporary(value: boolean | cdktf.IResolvable);
    resetTemporary(): void;
    get temporaryInput(): boolean | cdktf.IResolvable | undefined;
    private _variationType?;
    get variationType(): string;
    set variationType(value: string);
    get variationTypeInput(): string | undefined;
    private _clientSideAvailability;
    get clientSideAvailability(): FeatureFlagClientSideAvailabilityList;
    putClientSideAvailability(value: FeatureFlagClientSideAvailability[] | cdktf.IResolvable): void;
    resetClientSideAvailability(): void;
    get clientSideAvailabilityInput(): cdktf.IResolvable | FeatureFlagClientSideAvailability[] | undefined;
    private _customProperties;
    get customProperties(): FeatureFlagCustomPropertiesList;
    putCustomProperties(value: FeatureFlagCustomProperties[] | cdktf.IResolvable): void;
    resetCustomProperties(): void;
    get customPropertiesInput(): cdktf.IResolvable | FeatureFlagCustomProperties[] | undefined;
    private _defaults;
    get defaults(): FeatureFlagDefaultsOutputReference;
    putDefaults(value: FeatureFlagDefaults): void;
    resetDefaults(): void;
    get defaultsInput(): FeatureFlagDefaults | undefined;
    private _variations;
    get variations(): FeatureFlagVariationsList;
    putVariations(value: FeatureFlagVariations[] | cdktf.IResolvable): void;
    resetVariations(): void;
    get variationsInput(): cdktf.IResolvable | FeatureFlagVariations[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
